==> qtjambi-help-debuginfo-linux-x64-5.15.20.jar: sources/QtJambiHelp/QHelpContentModel_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtHelp/qhelpcontentwidget.h>
#include <QtCore/QHash>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/QVector>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qdatastream.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qmimedata.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

int __signal_method_indexes_QHelpContentModel_0(){
    static int result = QMetaMethod::fromSignal(&QHelpContentModel::contentsCreated).methodIndex();
    return result;
}


int __signal_method_indexes_QHelpContentModel_1(){
    static int result = QMetaMethod::fromSignal(&QHelpContentModel::contentsCreationStarted).methodIndex();
    return result;
}


// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QHelpContentModel::contentItemAt(QModelIndex)const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpContentModel_contentItemAt_1native_1cref_1QModelIndex_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID index0)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QHelpContentModel *__qt_this = QtJambiAPI::objectFromNativeId<QHelpContentModel>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpContentModel::contentItemAt(QModelIndex)const", __qt_this)
        const QModelIndex& __qt_index0 = QtJambiAPI::valueReferenceFromNativeId<QModelIndex>(index0);
        QHelpContentItem* __qt_return_value = __qt_this->contentItemAt(__qt_index0);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QHelpContentModel::createContents(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpContentModel_createContents_1native_1cref_1QString__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring customFilterName0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QHelpContentModel *__qt_this = QtJambiAPI::objectFromNativeId<QHelpContentModel>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpContentModel::createContents(QString)", __qt_this)
        QString  __qt_customFilterName0 = qtjambi_cast<QString>(__jni_env, customFilterName0);
        __qt_this->createContents(__qt_customFilterName0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QHelpContentModel::isCreatingContents()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpContentModel_isCreatingContents_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QHelpContentModel *__qt_this = QtJambiAPI::objectFromNativeId<QHelpContentModel>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpContentModel::isCreatingContents()const", __qt_this)
        __java_return_value = __qt_this->isCreatingContents();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QHelpContentModel::columnCount(QModelIndex)const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpContentModel_columnCount_1native_1cref_1QModelIndex_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID parent0)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QHelpContentModel *__qt_this = QtJambiAPI::objectFromNativeId<QHelpContentModel>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpContentModel::columnCount(QModelIndex)const", __qt_this)
        const QModelIndex& __qt_parent0 = QtJambiAPI::valueReferenceFromNativeId<QModelIndex>(parent0);
        __java_return_value = __qt_this->columnCount(__qt_parent0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QHelpContentModel::data(QModelIndex,int)const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpContentModel_data_1native_1cref_1QModelIndex_1int_1constfct__JJI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID index0,
 jint role1)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QHelpContentModel *__qt_this = QtJambiAPI::objectFromNativeId<QHelpContentModel>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpContentModel::data(QModelIndex,int)const", __qt_this)
        const QModelIndex& __qt_index0 = QtJambiAPI::valueReferenceFromNativeId<QModelIndex>(index0);
        QVariant __qt_return_value = __qt_this->data(__qt_index0, static_cast<int>(role1));
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QHelpContentModel::index(int,int,QModelIndex)const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpContentModel_index_1native_1int_1int_1cref_1QModelIndex_1constfct__JIIJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint row0,
 jint column1,
 QtJambiNativeID parent2)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QHelpContentModel *__qt_this = QtJambiAPI::objectFromNativeId<QHelpContentModel>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpContentModel::index(int,int,QModelIndex)const", __qt_this)
        const QModelIndex& __qt_parent2 = QtJambiAPI::valueReferenceFromNativeId<QModelIndex>(parent2);
        QModelIndex __qt_return_value = __qt_this->index(static_cast<int>(row0), static_cast<int>(column1), __qt_parent2);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QHelpContentModel::parent(QModelIndex)const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpContentModel_parent_1native_1cref_1QModelIndex_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID index0)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QHelpContentModel *__qt_this = QtJambiAPI::objectFromNativeId<QHelpContentModel>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpContentModel::parent(QModelIndex)const", __qt_this)
        const QModelIndex& __qt_index0 = QtJambiAPI::valueReferenceFromNativeId<QModelIndex>(index0);
        QModelIndex __qt_return_value = __qt_this->parent(__qt_index0);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QHelpContentModel::rowCount(QModelIndex)const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpContentModel_rowCount_1native_1cref_1QModelIndex_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID parent0)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QHelpContentModel *__qt_this = QtJambiAPI::objectFromNativeId<QHelpContentModel>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpContentModel::rowCount(QModelIndex)const", __qt_this)
        const QModelIndex& __qt_parent0 = QtJambiAPI::valueReferenceFromNativeId<QModelIndex>(parent0);
        __java_return_value = __qt_this->rowCount(__qt_parent0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QHelpContentModel(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerQObjectTypeInfo<QHelpContentModel>("QHelpContentModel", "io/qt/help/QHelpContentModel");
// BEGIN: function table
// END: function table

    registerMetaObject(typeId, QHelpContentModel::staticMetaObject, false,
            {
                SignalMetaInfo(/* 0 */ "contentsCreated", "Lio/qt/core/QObject$Signal0;", 0, __signal_method_indexes_QHelpContentModel_0),
                SignalMetaInfo(/* 1 */ "contentsCreationStarted", "Lio/qt/core/QObject$Signal0;", 0, __signal_method_indexes_QHelpContentModel_1)
            },
            [](const QMetaMethod& method, QList<ParameterInfo>& infos) {
                Q_UNUSED(infos)
                int methodIndex = method.methodIndex();
                if(methodIndex==__signal_method_indexes_QHelpContentModel_0()){ // contentsCreated()
                    infos << ParameterInfo(QMetaType::Void);
                    return true;
                }
                if(methodIndex==__signal_method_indexes_QHelpContentModel_1()){ // contentsCreationStarted()
                    infos << ParameterInfo(QMetaType::Void);
                    return true;
                }
                return false;
            });
// END: signal table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-help-debuginfo-linux-x64-6.5.3.jar: sources/QtJambiHelp/QHelpContentModel_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtHelp/qhelpcontentwidget.h>
#include <QtCore/QVariant>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/QList>
#include <QtCore/qsize.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qdatastream.h>
#include <QtCore/QStringList>
#include <QtCore/qmimedata.h>
#include <QtCore/QMap>
#include <QtCore/QHash>
#include <QtCore/qbytearray.h>
#include <QtCore/qobject.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qtimer.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qproperty.h>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qthread.h>
#include <QtCore/qmetaobject.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

int __signal_method_indexes_QHelpContentModel_0(){
    static int result = QMetaMethod::fromSignal(&QHelpContentModel::contentsCreated).methodIndex();
    return result;
}


int __signal_method_indexes_QHelpContentModel_1(){
    static int result = QMetaMethod::fromSignal(&QHelpContentModel::contentsCreationStarted).methodIndex();
    return result;
}


// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QHelpContentModel::contentItemAt(QModelIndex)const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpContentModel_contentItemAt_1native_1cref_1QModelIndex_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID index0)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QHelpContentModel *__qt_this = QtJambiAPI::objectFromNativeId<QHelpContentModel>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpContentModel::contentItemAt(QModelIndex)const", __qt_this)
        const QModelIndex& __qt_index0 = QtJambiAPI::valueReferenceFromNativeId<QModelIndex>(index0);
        QHelpContentItem* __qt_return_value = __qt_this->contentItemAt(__qt_index0);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QHelpContentModel::createContents(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpContentModel_createContents_1native_1cref_1QString__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring customFilterName0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QHelpContentModel *__qt_this = QtJambiAPI::objectFromNativeId<QHelpContentModel>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpContentModel::createContents(QString)", __qt_this)
        QString  __qt_customFilterName0 = qtjambi_cast<QString >(__jni_env, customFilterName0);
        __qt_this->createContents(__qt_customFilterName0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QHelpContentModel::isCreatingContents()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpContentModel_isCreatingContents_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QHelpContentModel *__qt_this = QtJambiAPI::objectFromNativeId<QHelpContentModel>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpContentModel::isCreatingContents()const", __qt_this)
        __java_return_value = __qt_this->isCreatingContents();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QHelpContentModel::columnCount(QModelIndex)const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpContentModel_columnCount_1native_1cref_1QModelIndex_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID parent0)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QHelpContentModel *__qt_this = QtJambiAPI::objectFromNativeId<QHelpContentModel>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpContentModel::columnCount(QModelIndex)const", __qt_this)
        const QModelIndex& __qt_parent0 = QtJambiAPI::valueReferenceFromNativeId<QModelIndex>(parent0);
        __java_return_value = __qt_this->columnCount(__qt_parent0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QHelpContentModel::data(QModelIndex,int)const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpContentModel_data_1native_1cref_1QModelIndex_1int_1constfct__JJI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID index0,
 jint role1)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QHelpContentModel *__qt_this = QtJambiAPI::objectFromNativeId<QHelpContentModel>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpContentModel::data(QModelIndex,int)const", __qt_this)
        const QModelIndex& __qt_index0 = QtJambiAPI::valueReferenceFromNativeId<QModelIndex>(index0);
        QVariant __qt_return_value = __qt_this->data(__qt_index0, static_cast<int>(role1));
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QHelpContentModel::index(int,int,QModelIndex)const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpContentModel_index_1native_1int_1int_1cref_1QModelIndex_1constfct__JIIJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint row0,
 jint column1,
 QtJambiNativeID parent2)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QHelpContentModel *__qt_this = QtJambiAPI::objectFromNativeId<QHelpContentModel>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpContentModel::index(int,int,QModelIndex)const", __qt_this)
        const QModelIndex& __qt_parent2 = QtJambiAPI::valueReferenceFromNativeId<QModelIndex>(parent2);
        QModelIndex __qt_return_value = __qt_this->index(static_cast<int>(row0), static_cast<int>(column1), __qt_parent2);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QHelpContentModel::parent(QModelIndex)const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpContentModel_parent_1native_1cref_1QModelIndex_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID index0)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QHelpContentModel *__qt_this = QtJambiAPI::objectFromNativeId<QHelpContentModel>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpContentModel::parent(QModelIndex)const", __qt_this)
        const QModelIndex& __qt_index0 = QtJambiAPI::valueReferenceFromNativeId<QModelIndex>(index0);
        QModelIndex __qt_return_value = __qt_this->parent(__qt_index0);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QHelpContentModel::rowCount(QModelIndex)const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpContentModel_rowCount_1native_1cref_1QModelIndex_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID parent0)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QHelpContentModel *__qt_this = QtJambiAPI::objectFromNativeId<QHelpContentModel>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpContentModel::rowCount(QModelIndex)const", __qt_this)
        const QModelIndex& __qt_parent0 = QtJambiAPI::valueReferenceFromNativeId<QModelIndex>(parent0);
        __java_return_value = __qt_this->rowCount(__qt_parent0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QHelpContentModel(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerQObjectTypeInfo<QHelpContentModel>("QHelpContentModel", "io/qt/help/QHelpContentModel");
// BEGIN: function table
// END: function table

    registerMetaObject(typeId, QHelpContentModel::staticMetaObject, false,
            {
                SignalMetaInfo(/* 0 */ "contentsCreated", "Lio/qt/core/QObject$Signal0;", 0, __signal_method_indexes_QHelpContentModel_0),
                SignalMetaInfo(/* 1 */ "contentsCreationStarted", "Lio/qt/core/QObject$Signal0;", 0, __signal_method_indexes_QHelpContentModel_1)
            },
            [](const QMetaMethod& method, QList<ParameterInfo>& infos) {
                Q_UNUSED(infos)
                int methodIndex = method.methodIndex();
                if(methodIndex==__signal_method_indexes_QHelpContentModel_0()){ // contentsCreated()
                    infos << ParameterInfo(QMetaType::Void);
                    return true;
                }
                if(methodIndex==__signal_method_indexes_QHelpContentModel_1()){ // contentsCreationStarted()
                    infos << ParameterInfo(QMetaType::Void);
                    return true;
                }
                return false;
            });
// END: signal table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
